@@ -24,21 +24,15 @@
 #include <core/networkpacket.h>
 #include <core/device.h>
 #include <core/daemon.h>
+#include <core/openconfig.h>
 
 #include "plugin_runcommand_debug.h"
 
 #define PACKET_TYPE_RUNCOMMAND QStringLiteral("kdeconnect.runcommand")
 
-#ifdef Q_OS_WIN
-#define COMMAND "cmd"
-#define ARGS "/c"
-
-#else
 #define COMMAND "/bin/sh"
 #define ARGS "-c"
 
-#endif
-
 K_PLUGIN_CLASS_WITH_JSON(RunCommandPlugin, "kdeconnect_runcommand.json")
 
 RunCommandPlugin::RunCommandPlugin(QObject* parent, const QVariantList& args)
@@ -68,10 +62,15 @@ bool RunCommandPlugin::receivePacket(const NetworkPacket& np)
         }
         const QJsonObject commandJson = value.toObject();
         qCInfo(KDECONNECT_PLUGIN_RUNCOMMAND) << "Running:" << COMMAND << ARGS << commandJson[QStringLiteral("command")].toString();
+#ifdef Q_OS_WIN
+        QProcess::startDetached(commandJson[QStringLiteral("command")].toString());
+#else
         QProcess::startDetached(QStringLiteral(COMMAND), QStringList()<< QStringLiteral(ARGS) << commandJson[QStringLiteral("command")].toString());
+#endif
         return true;
     } else if (np.has(QStringLiteral("setup"))) {
-        Daemon::instance()->openConfiguration(device()->id(), QStringLiteral("kdeconnect_runcommand"));
+        OpenConfig oc;
+        oc.openConfiguration(device()->id(), QStringLiteral("kdeconnect_runcommand"));
     }
 
     return false;
