@@ -41,8 +41,10 @@ class Q_DECL_EXPORT SystemvolumePlugin : public KdeConnectPlugin
     IMMDeviceEnumerator* deviceEnumerator;
     CMMNotificationClient* deviceCallback;
     QMap<QString, QPair<IAudioEndpointVolume *, CAudioEndpointVolumeCallback *>> sinkList;
+    QMap<QString, QString> idToNameMap;
 
     bool sendSinkList();
+    HRESULT setDefaultAudioPlaybackDevice(QString& name, bool enabled);
 };
 
 #endif // SYSTEMVOLUMEPLUGINWIN_H
